.. _series-docs:

======
Series
======

The series module implements series expansions as a function and many related
functions.

Contents
========

.. toctree::
   :titlesonly:

   series.rst
   sequences.rst
   fourier.rst
   formal.rst
   limitseq.rst
